#!/usr/bin/env bash

# Assuming that path contains the built binaries.
# And this script is called from the root directory.
which scram || ( echo "No SCRAM Found!" && exit 1 )
which scram_tests || ( echo "No SCRAM Tests Found!" && exit 1 )

scram_tests --gtest_filter=-*Performance*

if [[ "$?" -ne 0 ]]; then
  echo "SCRAM Tests Failed!"
  exit 1
fi

nosetests -w ./tests/ || ( echo "CMD-Line Call Tests Failed!" && exit 1 )
nosetests -w ./scripts/ || ( echo "Tests for Scripts Failed!" && exit 1 )

./scripts/fault_tree_generator.py -b 200 -c 5 \
  || ( echo "Can't generate a fault tree." && exit 1 )

scram --graph fault_tree.xml || ( echo "Can't Generate Graph!" && exit 1 )

dot -q -Tsvg Autogenerated_root.dot -o fault_tree.svg \
  || ( echo "Dot Failed." && exit 1 )

rm fault_tree.xml fault_tree.svg Autogenerated_root.dot \
  || ( echo "Problems with erasing temporary files" && exit 1 )

exit 0
